# Description of the module:

This module had been created to simplify the code available on https://github.com/charly077/MISP-privacy-aware-sharing-master-thesis.
This is also intended to make easier the creation of an integrated export module in MISP.

The module pypraware_misp (python privacy aware for MISP) is separated into two different subparts, the first is used for the "crypto systems" while the second one is used for normalisation.

For any question on this module, feel free to contact the author
